@@ -1,5 +1,8 @@
+from __future__ import annotations as _annotations
+
 from datetime import date, datetime, timedelta, timezone, tzinfo
-from typing import Any, Optional, Union
+from typing import Any
+from zoneinfo import ZoneInfo
 
 from ._numeric import IsNumeric
 from ._utils import Omit
@@ -15,15 +18,15 @@ class IsDatetime(IsNumeric[datetime]):
     def __init__(
         self,
         *,
-        approx: Optional[datetime] = None,
-        delta: Optional[Union[timedelta, int, float]] = None,
-        gt: Optional[datetime] = None,
-        lt: Optional[datetime] = None,
-        ge: Optional[datetime] = None,
-        le: Optional[datetime] = None,
+        approx: datetime | None = None,
+        delta: timedelta | int | float | None = None,
+        gt: datetime | None = None,
+        lt: datetime | None = None,
+        ge: datetime | None = None,
+        le: datetime | None = None,
         unix_number: bool = False,
         iso_string: bool = False,
-        format_string: Optional[str] = None,
+        format_string: str | None = None,
         enforce_tz: bool = True,
     ):
         """
@@ -126,12 +129,12 @@ class IsNow(IsDatetime):
     def __init__(
         self,
         *,
-        delta: Union[timedelta, int, float] = 2,
+        delta: timedelta | int | float = 2,
         unix_number: bool = False,
         iso_string: bool = False,
-        format_string: Optional[str] = None,
+        format_string: str | None = None,
         enforce_tz: bool = True,
-        tz: Union[None, str, tzinfo] = None,
+        tz: str | tzinfo | None = None,
     ):
         """
         Args:
@@ -141,8 +144,8 @@ class IsNow(IsDatetime):
             iso_string: whether to allow iso formatted strings in comparison
             format_string: if provided, `format_string` is used with `datetime.strptime` to parse strings
             enforce_tz: whether timezone should be enforced in comparison, see below for more details
-            tz: either a `pytz.timezone`, a `datetime.timezone` or a string which will be passed to `pytz.timezone`,
-                if provided now will be converted to this timezone.
+            tz: either a `ZoneInfo`, a `datetime.timezone` or a string which will be passed to `ZoneInfo`,
+                to get a timezone, if provided now will be converted to this timezone.
 
         ```py title="IsNow"
         from datetime import datetime, timezone
@@ -161,9 +164,7 @@ class IsNow(IsDatetime):
         ```
         """
         if isinstance(tz, str):
-            import pytz
-
-            tz = pytz.timezone(tz)
+            tz = ZoneInfo(tz)
 
         self.tz = tz
 
@@ -184,7 +185,8 @@ class IsNow(IsDatetime):
         if self.tz is None:
             return datetime.now()
         else:
-            return datetime.utcnow().replace(tzinfo=timezone.utc).astimezone(self.tz)
+            utc_now = datetime.now(tz=timezone.utc).replace(tzinfo=timezone.utc)
+            return utc_now.astimezone(self.tz)
 
     def prepare(self, other: Any) -> datetime:
         # update approx for every comparing, to check if other value is dirty equal
@@ -204,14 +206,14 @@ class IsDate(IsNumeric[date]):
     def __init__(
         self,
         *,
-        approx: Optional[date] = None,
-        delta: Optional[Union[timedelta, int, float]] = None,
-        gt: Optional[date] = None,
-        lt: Optional[date] = None,
-        ge: Optional[date] = None,
-        le: Optional[date] = None,
+        approx: date | None = None,
+        delta: timedelta | int | float | None = None,
+        gt: date | None = None,
+        lt: date | None = None,
+        ge: date | None = None,
+        le: date | None = None,
         iso_string: bool = False,
-        format_string: Optional[str] = None,
+        format_string: str | None = None,
     ):
         """
         Args:
@@ -280,7 +282,7 @@ class IsToday(IsDate):
         self,
         *,
         iso_string: bool = False,
-        format_string: Optional[str] = None,
+        format_string: str | None = None,
     ):
         """
         Args:
